==> nextcloud-app-calendar-1.5.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/hu.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Naptár",
    "%s has published the calendar \"%s\"" : "%s közzétette ezt a naptárt: \"%s\"",
    "Too many redirects. Aborting ..." : "Túl sok átirányítás. Megszakítás...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "A távoli szerver nem adott hozzáférést a naptárhoz (HTTP hiba: {%s})",
    "Error connecting to remote server" : "Hiba a távoli szerverhez való csatlahozásban",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Hiba a távoli szerver erőforrásainak lekérése közben. Lehetséges, hogy ez egy hibás tanúsítvány okozza.",
    "Error requesting resource on remote server" : "Hiba a távoli szerver erőforrásainak lekérése közben",
    "Individual" : "egyéni",
    "Group" : "Csoport",
    "Resource" : "Forrás",
    "Room" : "Szoba",
    "Unknown" : "Ismeretlen",
    "Required" : "Szükséges",
    "Optional" : "Opcionális",
    "Does not attend" : "Nem vesz részt",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Ismeretlen időzónában tartózkodik ({tz}), visszaállítás UTC-re",
    "Please create a calendar first." : "Először naptárat készítsen",
    "New event" : "Új esemény",
    "CalDAV address for clients" : "CalDAV cím a klienseknek",
    "Error saving WebCal-calendar" : "WebCal naptár mentési hiba",
    "WebDAV address for subscriptions" : "WebDAV cím a feliratkozásokhoz",
    "EMail has been sent." : "E-mail elküldve.",
    "There was an issue while sending your EMail." : "Probléma lépett fel az e-mail elküldése során.",
    "group" : "csoport",
    "Details" : "Részletek",
    "Attendees" : "Résztvevők",
    "Reminders" : "Emlékeztetők",
    "Repeating" : "Ismétlődő",
    "When shared show full event" : "Megosztáskor mutassa a teljes eseményt.",
    "When shared show only busy" : "Megosztáskor csak a foglaltságot mutassa",
    "When shared hide this event" : "Megosztáskor rejtse el ezt az eseményt",
    "Confirmed" : "Elfogadva",
    "Tentative" : "Kísérleti",
    "Cancelled" : "Megszakítva",
    "Please add a title!" : "Kérjük, töltse ki a címet!",
    "Please select a calendar!" : "Kérjük, válasszon egy naptárat!",
    "The event ends before it starts!" : "Az esemény végetér mielőtt elkezdődne!",
    "Global" : "Globális",
    "None" : "Egyik sem",
    "Every day" : "minden nap",
    "Every week" : "minden hét",
    "Every month" : "Minden hónap",
    "Every year" : "Minden év",
    "never" : "soha",
    "after" : "után",
    "How about getting started by importing some calendars?" : "Mi lenne, ha a meglévő naptárak importálásával kezdenénk?",
    "At time of event" : "az eseménnyel egy időben",
    "5 minutes before" : "5 perccel előtte",
    "10 minutes before" : "10 perccel előtte",
    "15 minutes before" : "15 perccel előtte",
    "30 minutes before" : "30 perccel előtte",
    "1 hour before" : "1 órával előtte",
    "2 hours before" : "2 órával előtte",
    "Custom" : "egyéni",
    "Audio" : "Hang",
    "E Mail" : "E-mail",
    "Pop up" : "Felugró ablak",
    "sec" : "mp",
    "min" : "perc",
    "hours" : "óra",
    "days" : "nap",
    "week" : "hét",
    "before" : "előtte",
    "start" : "kezdet",
    "end" : "vég",
    "Editing reminders of unknown type not supported." : "Ismeretlen típusú emlékeztetős szerkesztése nem támogatott.",
    "Week {number} of {year}" : "{year} év {number}. hete",
    "Successfully imported" : "Sikeresen importálva!",
    "Partially imported, 1 failure" : "Részben importálva, 1 hiba",
    "Partially imported, {n} failures" : "Részben importálva, {n} hiba",
    "Audio alarm" : "Hangriasztás",
    "Pop-up" : "Felugró ablak",
    "E-Mail" : "E-mail",
    "{type} {time} before the event starts" : "{type} {time} idő múlva kezdődik az esemény",
    "{type} {time} before the event ends" : "{type} {time} idő múlva végződik az esemény",
    "{type} {time} after the event starts" : "{type} {time} esemény kezdete után",
    "{type} {time} after the event ends" : "{type} {time} esemény vége után",
    "{type} at the event's start" : "{type} az esemény kezdetekor",
    "{type} at the event's end" : "{type} az esemény végén",
    "{type} at {time}" : "{type} ekkor: {time}",
    "{calendar} shared by {owner}" : "{calendar} megosztója: {owner}",
    "Please enter a valid WebCal-URL" : "Kérlek adj meg egy érvényes WebCal-URL-t",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Komoly hiba van a webcal proxynál. További információkért kérlek vedd fel a kapcsolatot a rendszergazdával.",
    "Title of the Event" : "Az esemény címe",
    "Starts" : "Kezdődik",
    "Ends" : "Véget ér",
    "All day Event" : "Egész napos esemény",
    "Delete" : "Törlés",
    "Cancel" : "Mégsem",
    "More ..." : "Bővebben...",
    "Create" : "Létrehozás",
    "Update" : "Frissítés",
    "Close" : "Bezárás",
    "Location" : "Hely",
    "Description" : "Leírás",
    "Event status" : "Esemény állapot",
    "Visibility when sharing" : "Láthatóság megosztáskor",
    "Export" : "Exportálás",
    "%s has published the calendar %s" : "%s közzétette ezt a naptárt: \"%s\"",
    "Hello," : "Szia!",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Szeretnénk tájékoztatni, hogy %s közzétette ezt a naptárt: {boldstart}%s{boldend}.",
    "Click here to access it" : "Kattints ide a hozzáféréshez",
    "Cheers!" : "Üdv!",
    "We wanted to inform you that %s has published the calendar %s." : "Szeretnénk tájékoztatni, hogy %s közzétette ezt a naptárt: %s.",
    "Click on the link below to access it" : "A hozzáféréshez kattints az alábbi hivatkozásra",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Egy fennálló hiba miatt a naptár jelenleg nem képes támogatni az asset pipeline funkciót.",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Kérlek vedd fel a kapcsolatot a rendszergazdáddal és kérd meg, hogy tiltsa le az \"asset-pipeline.enabled\" beállítási lehetőséget.",
    "Day" : "Nap",
    "Week" : "Hét",
    "Month" : "Hónap",
    "Today" : "Ma",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Néhány esemény hibás ebben a naptárban. További információkért kérek ellenőrizd a JS konzolt.",
    "Share Calendar" : "A naptár megosztása",
    "Shared" : "Megosztott",
    "More" : "Több",
    "Edit" : "Szerkesztés",
    "Link" : "Hivatkozás",
    "iCal link" : "iCal hivatkozás",
    "Download" : "Letöltés",
    "Share with users or groups" : "Megosztás felhasználókkal vagy csoportokkal",
    "can edit" : "szerkesztheti",
    "Share link" : "Megosztás hivatkozással",
    "Public access" : "Nyilvános hozzáférés",
    "Email link to person" : "Hivatkozás elküldése e-mail címre",
    "Send" : "Küldés",
    "New Calendar" : "Új naptár",
    "Name" : "Név",
    "New Subscription" : "Új feliratkozás",
    "Go back" : "Vissza",
    "Go forward" : "Előre",
    "Edit event" : "Esemény szerkesztése",
    "Delete Event" : "Esemény törlése",
    "Save Event" : "Esemény mentése",
    "Time" : "Idő",
    "Type" : "Típus",
    "Relative" : "Relatív",
    "Absolute" : "Abszolút",
    "Repeat" : "Ismétlés",
    "times every" : "mindennyiszer",
    "Add" : "Hozzáadás",
    "E-Mail address of attendee" : "Résztvevők E-Mail címe",
    "Please add your email address in the personal settings in order to add attendees." : "Kérem adja meg az email címét a személyes beállításokban, hogy résztvevőket tudjon hozzáadni.",
    "from" : "feladó",
    "to" : "címzett",
    "This event's repeating rule is not supported yet." : "Ennek az eseménynek az ismétlődő szabálya még nem támogatott.",
    "Support for advanced rules will be added with subsequent updates." : "Az összetett szabályok támogatása későbbi frissítések alkalmával lesz majd hozzáadva.",
    "Reset repeating rule" : "Ismétlődő szabály törlése",
    "Repeat every ..." : "Ismétlődjön minden ...",
    "end repeat ..." : "ismétlődés vége ...",
    "times" : "alkalommal",
    "Import Calendars" : "Naptár importálása",
    "Import canceled" : "Importálás megszakítva.",
    "Analyzing calendar" : "Naptár analizálása",
    "The file contains objects incompatible with the selected calendar" : "A fájlban olyan objektumok találhatók amik nem kompatibilisek a naptárral.",
    "New calendar" : "Új naptár",
    "File is empty" : "A fájl üres",
    "Import scheduled" : "Importálás beütemezve",
    "Publish URL" : "Közzétételi URL",
    "Settings & import" : "Beállítások és Import",
    "Skip simple event editor" : "Váltás az egyszerű esemény szerkesztőre",
    "Show week numbers" : "Hetek számának megjelenítése",
    "Import calendar" : "Naptár importálása",
    "No Calendars selected for import" : "Nincs importálásra kiválasztott naptár",
    "Primary CalDAV address" : "Elsődleges CalDAV cím",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV cím"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-calendar-1.5.6-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/hu.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Naptár",
    "%s has published the calendar »%s«" : "%s közzétette ezt a naptárt: »%s«",
    "Hello," : "Szia!",
    "We wanted to inform you that %s has published the calendar »%s«." : "Szeretnénk tájékoztatni, hogy %s közzétette ezt a naptárt: %s.",
    "Open »%s«" : "»%s« megnyitása",
    "Cheers!" : "Üdv!",
    "Recipient" : "Címzett",
    "Too many redirects. Aborting ..." : "Túl sok átirányítás. Megszakítás...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "A távoli szerver nem adott hozzáférést a naptárhoz (HTTP hiba: {%s})",
    "Error connecting to remote server" : "Hiba a távoli szerverhez való csatlahozásban",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Hiba a távoli szerver erőforrásainak lekérése közben. Lehetséges, hogy ez egy hibás tanúsítvány okozza.",
    "Error requesting resource on remote server" : "Hiba a távoli szerver erőforrásainak lekérése közben",
    "Individual" : "egyéni",
    "Group" : "Csoport",
    "Resource" : "Forrás",
    "Room" : "Szoba",
    "Unknown" : "Ismeretlen",
    "Required" : "Szükséges",
    "Optional" : "Opcionális",
    "Does not attend" : "Nem vesz részt",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Ismeretlen időzónában tartózkodik ({tz}), visszaállítás UTC-re",
    "Please create a calendar first." : "Először naptárat készítsen",
    "New event" : "Új esemény",
    "CalDAV address for clients" : "CalDAV cím a klienseknek",
    "Error saving WebCal-calendar" : "WebCal naptár mentési hiba",
    "WebDAV address for subscriptions" : "WebDAV cím a feliratkozásokhoz",
    "Email has been sent." : "E-mail elküldve.",
    "There was an issue while sending your email." : "Probléma lépett fel az e-mail elküldése során.",
    "group" : "csoport",
    "Details" : "Részletek",
    "Attendees" : "Résztvevők",
    "Reminders" : "Emlékeztetők",
    "Repeating" : "Ismétlődő",
    "When shared show full event" : "Megosztáskor mutassa a teljes eseményt.",
    "When shared show only busy" : "Megosztáskor csak a foglaltságot mutassa",
    "When shared hide this event" : "Megosztáskor rejtse el ezt az eseményt",
    "Confirmed" : "Elfogadva",
    "Tentative" : "Kísérleti",
    "Cancelled" : "Megszakítva",
    "Please add a title." : "Kérjük, töltse ki a címet.",
    "Please select a calendar." : "Kérjük, válasszon egy naptárat.",
    "The event can not end before it starts." : "Az esemény vége nem lehet korábbi a kezdeténél.",
    "Global" : "Globális",
    "None" : "Egyik sem",
    "Every day" : "minden nap",
    "Every week" : "minden hét",
    "Every month" : "Minden hónap",
    "Every year" : "Minden év",
    "never" : "soha",
    "after" : "után",
    "How about getting started by importing some calendars?" : "Mi lenne, ha a meglévő naptárak importálásával kezdenénk?",
    "At time of event" : "az eseménnyel egy időben",
    "5 minutes before" : "5 perccel előtte",
    "10 minutes before" : "10 perccel előtte",
    "15 minutes before" : "15 perccel előtte",
    "30 minutes before" : "30 perccel előtte",
    "1 hour before" : "1 órával előtte",
    "2 hours before" : "2 órával előtte",
    "Custom" : "egyéni",
    "Audio" : "Hang",
    "Email" : "E-mail",
    "Pop-up" : "Felugró ablak",
    "sec" : "mp",
    "min" : "perc",
    "hours" : "óra",
    "days" : "nap",
    "week" : "hét",
    "before" : "előtte",
    "start" : "kezdet",
    "end" : "vég",
    "Editing reminders of unknown type not supported." : "Ismeretlen típusú emlékeztetős szerkesztése nem támogatott.",
    "Week {number} of {year}" : "{year} év {number}. hete",
    "Successfully imported" : "Sikeresen importálva!",
    "Partially imported, 1 failure" : "Részben importálva, 1 hiba",
    "Partially imported, {n} failures" : "Részben importálva, {n} hiba",
    "Audio alarm" : "Hangriasztás",
    "{type} {time} before the event starts" : "{type} {time} idő múlva kezdődik az esemény",
    "{type} {time} before the event ends" : "{type} {time} idő múlva végződik az esemény",
    "{type} {time} after the event starts" : "{type} {time} esemény kezdete után",
    "{type} {time} after the event ends" : "{type} {time} esemény vége után",
    "{type} at the event's start" : "{type} az esemény kezdetekor",
    "{type} at the event's end" : "{type} az esemény végén",
    "{type} at {time}" : "{type} ekkor: {time}",
    "{calendar} shared by {owner}" : "{calendar} megosztója: {owner}",
    "Please enter a valid WebCal-URL" : "Kérlek adj meg egy érvényes WebCal-URL-t",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Komoly hiba van a webcal proxynál. További információkért kérlek vedd fel a kapcsolatot a rendszergazdával.",
    "Title of the Event" : "Az esemény címe",
    "Starts" : "Kezdődik",
    "Ends" : "Véget ér",
    "All day Event" : "Egész napos esemény",
    "Delete" : "Törlés",
    "Cancel" : "Mégsem",
    "More ..." : "Bővebben...",
    "Create" : "Létrehozás",
    "Update" : "Frissítés",
    "Close" : "Bezárás",
    "Location" : "Hely",
    "Description" : "Leírás",
    "Event status" : "Esemény állapot",
    "Visibility when sharing" : "Láthatóság megosztáskor",
    "Export" : "Exportálás",
    "%s has published the calendar %s" : "%s közzétette ezt a naptárt: \"%s\"",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Szeretnénk tájékoztatni, hogy %s közzétette ezt a naptárt: {boldstart}%s{boldend}.",
    "Click here to access it" : "Kattints ide a hozzáféréshez",
    "We wanted to inform you that %s has published the calendar %s." : "Szeretnénk tájékoztatni, hogy %s közzétette ezt a naptárt: %s.",
    "Click on the link below to access it" : "A hozzáféréshez kattints az alábbi hivatkozásra",
    "Day" : "Nap",
    "Week" : "Hét",
    "Month" : "Hónap",
    "Today" : "Ma",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Néhány esemény hibás ebben a naptárban. További információkért kérek ellenőrizd a JS konzolt.",
    "Share Calendar" : "A naptár megosztása",
    "Shared" : "Megosztott",
    "More" : "Több",
    "Edit" : "Szerkesztés",
    "Link" : "Hivatkozás",
    "iCal link" : "iCal hivatkozás",
    "Download" : "Letöltés",
    "Share with users or groups" : "Megosztás felhasználókkal vagy csoportokkal",
    "can edit" : "szerkesztheti",
    "Share link" : "Megosztás hivatkozással",
    "Public access" : "Nyilvános hozzáférés",
    "Email link to person" : "Hivatkozás elküldése e-mail címre",
    "Send" : "Küldés",
    "New Calendar" : "Új naptár",
    "Name" : "Név",
    "New Subscription" : "Új feliratkozás",
    "Go back" : "Vissza",
    "Go forward" : "Előre",
    "Calendar does not exist" : "Naptár nem létezik",
    "Maybe you got a wrong link or the calendar was unshared?" : "Lehet, hogy rossz linket kapott, esetleg nem volt megosztva a naptár?",
    "Edit event" : "Esemény szerkesztése",
    "Delete Event" : "Esemény törlése",
    "Save Event" : "Esemény mentése",
    "Time" : "Idő",
    "Type" : "Típus",
    "Relative" : "Relatív",
    "Absolute" : "Abszolút",
    "Repeat" : "Ismétlés",
    "times every" : "mindennyiszer",
    "Add" : "Hozzáadás",
    "Email address of attendee" : "Résztvevők e-mail címe",
    "Please add your email address in the personal settings in order to add attendees." : "Kérem adja meg az email címét a személyes beállításokban, hogy résztvevőket tudjon hozzáadni.",
    "from" : "feladó",
    "to" : "címzett",
    "This event's repeating rule is not supported yet." : "Ennek az eseménynek az ismétlődő szabálya még nem támogatott.",
    "Support for advanced rules will be added with subsequent updates." : "Az összetett szabályok támogatása későbbi frissítések alkalmával lesz majd hozzáadva.",
    "Reset repeating rule" : "Ismétlődő szabály törlése",
    "Repeat every ..." : "Ismétlődjön minden ...",
    "end repeat ..." : "ismétlődés vége ...",
    "times" : "alkalommal",
    "Import Calendars" : "Naptár importálása",
    "Import canceled" : "Importálás megszakítva.",
    "Analyzing calendar" : "Naptár analizálása",
    "The file contains objects incompatible with the selected calendar" : "A fájlban olyan objektumok találhatók amik nem kompatibilisek a naptárral.",
    "New calendar" : "Új naptár",
    "File is empty" : "A fájl üres",
    "Import scheduled" : "Importálás beütemezve",
    "%s shared the calendar <strong>%s</strong> with you" : "%s megosztotta <strong>%s</strong> naptárát veled",
    "Embed" : "Beágyazott",
    "Iframe to integrate" : "Beépítendő iframe",
    "Publish URL" : "Közzétételi URL",
    "Settings & import" : "Beállítások és Import",
    "Skip simple event editor" : "Váltás az egyszerű esemény szerkesztőre",
    "Show week numbers" : "Hetek számának megjelenítése",
    "Import calendar" : "Naptár importálása",
    "No Calendars selected for import" : "Nincs importálásra kiválasztott naptár",
    "Primary CalDAV address" : "Elsődleges CalDAV cím",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV cím",
    "Subscribe" : "Feliratkozás"
},
"nplurals=2; plural=(n != 1);");
